function [X, R] = imstack2vectors(S, MASK)
% [X, R] = imstack2vectors(S, MASK) formira vektore od visedimenzionalnog
% niza S koji je dimenzionalnosti M*N*n i predstavlja niz od n
% registrovanih slika od kojih je svaka dimenzija M*N. Vektori su
% organizovani kao redovi matrice X. 
% MASK je logicki ili numericki niz dimenzija M*N koji ima nenulte
% vrijednosti (logicke 1 ako je u pitanju logicki niz) na lokacijama na
% kojima se nalaze elementi S koji ce se koristiti u formiranju niza X, a
% vrijednosti 0 na lokacijama koje se ignorisu. Broj redova u X ce biti
% jednak broju nenultih elemenata u MASK. Ako se MASK izostavi svih M*N
% lokacija se koristi za formiranje X. Jednostavan nacin da se interaktivno
% formira MASK je funkcija roipoly.
% R je matrica u cijim se redovima nalaze koordinate lokacija u MASK sa
% kojih su uzeti vektori iz S.
%
% Preuzeto iz DIPUM.

[M, N, n] = size(S);
if nargin == 1
    MASK = true(M, N);
else
    MASK = MASK ~= 0;
end

[I, J] = find(MASK);
R = [I, J];

Q = M*N;
X = reshape(S, Q, n);

MASK = reshape(MASK, Q, 1);
X = X(MASK, :);
