function d = mahalanobis(varargin)
% D = MAHALANOBIS(Y, X) izracunava Mahalanobisovu udaljenost izmedju svakog
% vektora u Y i srednje vrijednosti (centroida) vektora u X i vraca
% rezultat u vektoru D cija je duzina size(Y, 1). Pretpostavka je da se
% vektori nalaze u redovima matrica X i Y.
%
% D = MAHALANOBIS(Y, CX, MX) izracunava Mahalanobisovu udaljenost izmedju
% svakog vektora u Y i zadatog vektora srednjih vrijednosti MX. Rezultati
% su u vektoru D cija je duzina size(Y, 1). Pretpostavka je da se vektori
% nalaze u redovima matrice Y.
% Pored vektora srednjih vrijednosti potrebno je zadati i kovarijansnu
% matricu CX. 
%
% Preuzeto iz DIPUM.

param = varargin;
Y = param{1};
ny = size(Y, 1);

if length(param) == 2
    X = param{2};
    mx = mean(X);
    Cx = cov(X);
elseif length(param) == 3
    Cx = param{2};
    mx = param{3};
else
    error('Pogresan broj ulaznih argumenata!');
end

mx = mx(:)';
Yc = Y - repmat(mx, ny, 1);
% Yc/Cx je tacnije i brze od Yc*inv(Cx)
d = sum(Yc/Cx.*Yc, 2);

